package com.ynet.life.platform.action;

import cn.hutool.crypto.SecureUtil;
import com.alibaba.fastjson.JSONObject;
import com.ynet.gene.log.GENELog;
import com.ynet.life.action.IdWorker;
import com.ynet.life.util.PropertiesFile;
import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLDecoder;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Properties;
import java.util.regex.Pattern;

/* loaded from: com_ynet_life_platform_action.jar:com/ynet/life/platform/action/YQSendMsgUtils.class */
public class YQSendMsgUtils {
    private static final String CCC_COMPONENT = "【【调用（短消息平台）】】";
    private static final String INSERT_SMS_SQL = "INSERT INTO fsp_sms_flow_info (SPI_FLOWNO,SPI_SENDORG,SPI_USERID,SPI_CONTENT,SPI_MOBILES,SPI_MOBILECOUNT,SPI_RETURNCODE,SPI_RETURNMSG,SPI_RETURNWHOLEMSG,SPI_MSGID,SPI_SUBMITTIME,SPI_TYPE,SPI_REMAIN_POIN) VALUES (?,?,?,?,?,?,?,?,?,?,NOW(),?,?)";
    private static final String ACTION_SEND = "send";
    private static final String ACTION_QUERY = "query";
    private static final String ACTION_OVERAGE = "overage";
    private static final String RT = "json";
    private static final String EXTNO = "";
    private static final String SEND_TIME = "";
    private static final String CONTENT_SIGN = "【园易融】";
    private String url;
    private String stateUrl;
    private String appId;
    private String userName;
    private String password;
    private static final String REGEX_PHONE = "^1(3[0-9]|4[01456879]|5[0-35-9]|6[2567]|7[0-8]|8[0-9]|9[0-35-9])\\d{8}$";

    public String sendMsg(String mobileNos, String sendMsg, boolean isContainSign) throws Exception {
        GENELog.log(CCC_COMPONENT, GENELog.INFO, 0, "【发送短信】开始");
        boolean isCorrect = true;
        StringBuilder errorMobiles = new StringBuilder();
        if (mobileNos != null && mobileNos.equals("")) {
            isCorrect = false;
        }
        if (isCorrect) {
            for (String m : mobileNos.split(",")) {
                if (!Pattern.matches(REGEX_PHONE, m)) {
                    isCorrect = false;
                    errorMobiles.append(m);
                }
            }
        }
        if (!isCorrect) {
            throw new Exception("手机号格式错误[" + errorMobiles.toString() + "]");
        }
        getInterfaceProperties();
        Date nowDate = new Date();
        String timeStamp = new SimpleDateFormat("yyyyMMddHHmmss").format(nowDate);
        String sign = SecureUtil.md5(String.valueOf(this.userName) + this.password + timeStamp);
        if (!isContainSign) {
            sendMsg = CONTENT_SIGN.concat(String.valueOf(sendMsg));
        }
        String requestParam = "action=send&rt=json&userid=" + this.appId + "&timestamp=" + timeStamp + "&sign=" + sign + "&mobile=" + mobileNos + "&content=" + sendMsg + "&sendTime=&extno=";
        return sendData(requestParam, this.url);
    }

    public String getMsgState(String count) throws Exception {
        getInterfaceProperties();
        Date nowDate = new Date();
        String timeStamp = new SimpleDateFormat("yyyyMMddHHmmss").format(nowDate);
        String sign = SecureUtil.md5(String.valueOf(this.userName) + this.password + timeStamp);
        String statusNumString = "";
        if (count != null && count != "") {
            statusNumString = "&statusNum=".concat(String.valueOf(count));
        }
        String requestParam = "action=query&rt=json&userid=" + this.appId + "&timestamp=" + timeStamp + "&sign=" + sign + statusNumString;
        return sendData(requestParam, this.stateUrl);
    }

    public String getMsgRage() throws Exception {
        getInterfaceProperties();
        Date nowDate = new Date();
        String timeStamp = new SimpleDateFormat("yyyyMMddHHmmss").format(nowDate);
        String sign = SecureUtil.md5(String.valueOf(this.userName) + this.password + timeStamp);
        String requestParam = "action=overage&rt=json&userid=" + this.appId + "&timestamp=" + timeStamp + "&sign=" + sign;
        return sendData(requestParam, this.url);
    }

    public String sendData(String param, String paramUrl) throws Exception {
        GENELog.log(CCC_COMPONENT, GENELog.INFO, 0, "发送参数".concat(String.valueOf(param)));
        String result = "";
        HttpURLConnection conn = (HttpURLConnection) new URL(paramUrl).openConnection();
        conn.setRequestMethod("POST");
        conn.setRequestProperty("Connection", "Keep-Alive");
        conn.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
        conn.setDoOutput(true);
        conn.setDoInput(true);
        conn.setUseCaches(false);
        conn.setConnectTimeout(60000);
        GENELog.log(CCC_COMPONENT, GENELog.INFO, 0, "开始建立接口连接");
        conn.connect();
        OutputStream out = conn.getOutputStream();
        byte[] data = param.getBytes("UTF-8");
        out.write(data);
        out.flush();
        out.close();
        int returnCode = conn.getResponseCode();
        GENELog.log(CCC_COMPONENT, GENELog.INFO, 0, "接口连接返回码".concat(String.valueOf(returnCode)));
        if (returnCode == 200) {
            InputStream in = conn.getInputStream();
            BufferedReader br = new BufferedReader(new InputStreamReader(in));
            StringBuffer sb = new StringBuffer();
            while (true) {
                String s = br.readLine();
                if (s == null) {
                    break;
                }
                sb.append(s);
            }
            if (sb.length() > 0) {
                result = URLDecoder.decode(sb.toString(), "UTF-8");
            }
            GENELog.log(CCC_COMPONENT, GENELog.INFO, 0, "接口返回成功，返回结果：".concat(String.valueOf(result)));
            if (in != null) {
                in.close();
            }
            if (conn != null) {
                conn.disconnect();
            }
            return result;
        }
        throw new Exception("连接失败,接口返回：".concat(String.valueOf(returnCode)));
    }

    private void getInterfaceProperties() {
        Properties properties = PropertiesFile.getProperties("/properties/YQSendMessagePath.properties");
        String profile = properties.getProperty("profile");
        this.url = properties.getProperty(String.valueOf(profile) + ".url");
        this.appId = properties.getProperty(String.valueOf(profile) + ".appId");
        this.userName = properties.getProperty(String.valueOf(profile) + ".userName");
        this.password = properties.getProperty(String.valueOf(profile) + ".password");
        this.stateUrl = properties.getProperty(String.valueOf(profile) + ".stateUrl");
    }

    public String sendMessage(Connection connection, String sendBranch, String sendUserNo, String sendMsg, String mobiles, String mobilCount, String type, boolean isContainSign) throws Exception {
        if (sendBranch == null) {
            sendBranch = "";
        }
        if (sendUserNo == null) {
            sendUserNo = "";
        }
        if (sendMsg == null) {
            sendMsg = "";
        }
        if (mobiles == null) {
            mobiles = "";
        }
        if (type == null) {
            type = "";
        }
        String msgId = "";
        String status = "";
        String explain = "";
        String remainPoint = "";
        String receiveMsg = "";
        try {
            try {
                String returnJson = sendMsg(mobiles, sendMsg, isContainSign);
                if (!returnJson.equals("")) {
                    JSONObject jo = JSONObject.parseObject(returnJson);
                    if (jo.containsKey("ReturnStatus")) {
                        status = getJSONObjectValue(jo, "ReturnStatus");
                        msgId = getJSONObjectValue(jo, "TaskID");
                        explain = getJSONObjectValue(jo, "Message");
                        remainPoint = getJSONObjectValue(jo, "RemainPoint");
                        receiveMsg = returnJson;
                    }
                }
                return returnJson;
            } catch (Exception e) {
                GENELog.log(CCC_COMPONENT, GENELog.INFO, 0, "短信发送异常：".concat(String.valueOf(e)));
                throw e;
            }
        } finally {
            IdWorker idWorker = IdWorker.getInstance();
            String[] mobileNoArray = mobiles.split(",");
            PreparedStatement ps = connection.prepareStatement(INSERT_SMS_SQL);
            for (String m : mobileNoArray) {
                ps.setString(1, String.valueOf(idWorker.nextId()));
                ps.setString(2, sendBranch);
                ps.setString(3, sendUserNo);
                ps.setString(4, sendMsg);
                ps.setString(5, m);
                ps.setString(6, "1");
                ps.setString(7, status);
                ps.setString(8, explain);
                ps.setString(9, receiveMsg);
                ps.setString(10, msgId);
                ps.setString(11, type);
                ps.setString(12, remainPoint);
                ps.addBatch();
            }
            ps.executeBatch();
            connection.commit();
            if (ps != null) {
                ps.close();
            }
        }
    }

    public String getJSONObjectValue(JSONObject jo, String key) {
        String string = jo.getString(key);
        String result = string;
        if (string == null) {
            result = "";
        }
        return result;
    }
}
